@@ -4,8 +4,8 @@
 
 """Daemon Component
 
-Component to daemonizae a sytem into the background and detach it from it's
-controlling PTY. Supports pid file writing, logging stdin, stdout and stderr
+Component to daemonizae a system into the background and detach it from its
+controlling PTY. Supports PID file writing, logging stdin, stdout and stderr
 and changing the current working directory.
 """
 
@@ -19,7 +19,7 @@ class Daemonize(Event):
 
     This event can be fired to notify the `Daemon` Component to begin the
     "daemonization" process. This event is (*by default*) used
-    automatically by the `Daemon` Component in it's "started" Event
+    automatically by the `Daemon` Component in its "started" Event
     Handler (*This behavior can be overridden*).
 
     Arguments: *None*
@@ -90,14 +90,14 @@ class Daemon(BaseComponent):
             pid = os.fork()
             if pid > 0:
                 # Exit first parent
-                raise SystemExit, 0
-        except OSError, e:
+                os._exit(0)
+        except OSError as e:
             print >> sys.stderr, "fork #1 failed: (%d) %s\n" % (errno, str(e))
-            raise SystemExit, 1
+            raise SystemExit(1)
 
         # Decouple from parent environment.
         os.chdir(self._path)
-        os.umask(077)
+        os.umask(0o077)
         os.setsid()
 
         # Do second fork.
@@ -105,17 +105,17 @@ class Daemon(BaseComponent):
             pid = os.fork()
             if pid > 0:
                 # Exit second parent
-                raise SystemExit, 0
-        except OSError, e:
+                os._exit(0)
+        except OSError as e:
             print >> sys.stderr, "fork #2 failed: (%d) %s\n" % (e, str(e))
-            raise SystemExit, 1
+            raise SystemExit(1)
 
         # Now I am a daemon!
 
         # Redirect standard file descriptors.
         si = open(self._stdin, "r")
         so = open(self._stdout, "a+")
-        se = open(self._stderr, "a+", 0)
+        se = open(self._stderr, "a+")
         os.dup2(si.fileno(), sys.stdin.fileno())
         os.dup2(so.fileno(), sys.stdout.fileno())
         os.dup2(se.fileno(), sys.stderr.fileno())
@@ -129,5 +129,5 @@ class Daemon(BaseComponent):
 
     @handler("registered")
     def _on_registered(self, component, manager):
-        if component == self and manager.root.running:
+        if component == self and manager == self and manager.root.running:
             self.push(Daemonize())
