@@ -7,25 +7,26 @@
 This package contains the essential core parts of the circuits framework.
 """
 
-from handlers import handler
+from .handlers import handler
 
-from events import Event
-from manager import Manager
-from components import BaseComponent, Component
+from .events import Event
+from .loader import Loader
+from .manager import Manager
+from .components import BaseComponent, Component
 
-from values import Value
-from futures import future
+from .values import Value
+from .futures import future
 
-from timers import Timer
+from .timers import Timer
 
 try:
-    from bridge import Bridge
+    from .bridge import Bridge
 except:
-    Bridge = None
+     Bridge = None
 
-from pools import Pool
-from workers import Task, Worker
-from debugger import Debugger
+from .pools import Pool
+from .workers import Task, Worker
+from .debugger import Debugger
 
 __all__ = ("handler", "BaseComponent", "Component", "Event",
         "future", "Pool", "Task", "Worker",
