@@ -19,13 +19,13 @@ uses the UDP protocol and as such events cannot be guaranteed of their
 order or delivery.
 """
 
-from StringIO import StringIO
+from io import BytesIO
 from pickle import dumps, Unpickler
 
-from handlers import handler
-from components import BaseComponent
-from values import Value, ValueChanged
-from events import Event, Registered, Unregistered, Started, Stopped
+from .handlers import handler
+from .components import BaseComponent
+from .values import Value, ValueChanged
+from .events import Event, Registered, Unregistered, Started, Stopped
 
 from circuits.net.sockets import Write
 
@@ -74,7 +74,7 @@ class Bridge(BaseComponent):
             self._values[id].value = obj.value
 
     def _reader(self, data):
-        unpickler = Unpickler(StringIO(data))
+        unpickler = Unpickler(BytesIO(data))
 
         while True:
             try:
