@@ -4,24 +4,25 @@
 
 """Components
 
-This module definse the BaseComponent and the subclassed Component
+This module defines the BaseComponent and the subclass Component
 """
 
 from itertools import chain
 from types import MethodType
 from inspect import getmembers
 
-from utils import findroot
-from manager import Manager
-from handlers import HandlersType
-from events import Registered, Unregistered
+from .utils import findroot
+from .manager import Manager
+from .handlers import HandlerMetaClass, handler
+from .events import Registered, Unregistered
+import collections
 
 class BaseComponent(Manager):
     """Base Component
 
     This is the Base of the Component which manages registrations to other
     components or managers. Every Base Component and thus Component has a
-    unique Channel that is used as a separation of concern for it's registered
+    unique Channel that is used as a separation of concern for its registered
     Event Handlers. By default, this Channels is None (or also known as the
     Global Channel).
 
@@ -42,12 +43,25 @@ class BaseComponent(Manager):
     channel = "*"
 
     def __new__(cls, *args, **kwargs):
-        """TODO Work around for Python bug.
+        self = super(BaseComponent, cls).__new__(cls)
 
-        Bug: http://bugs.python.org/issue5322
-        """
+        handlers = dict([(k, v) for k, v in cls.__dict__.items()
+                if getattr(v, "handler", False)])
 
-        return object.__new__(cls)
+        overridden = lambda x: x in handlers and handlers[x].override
+
+        for base in cls.__bases__:
+            if issubclass(cls, base):
+                for k, v in list(base.__dict__.items()):
+                    p1 = isinstance(v, collections.Callable)
+                    p2 = getattr(v, "handler", False)
+                    p3 = overridden(k)
+                    if p1 and p2 and not p3:
+                        name = "%s_%s" % (base.__name__, k)
+                        method = MethodType(v, self)
+                        setattr(self, name, method)
+
+        return self
 
     def __init__(self, *args, **kwargs):
         "initializes x; see x.__class__.__doc__ for signature"
@@ -64,7 +78,7 @@ class BaseComponent(Manager):
 
     def _registerHandlers(self, manager=None):
         if manager is None:
-            p = lambda x: callable(x) and getattr(x, "handler", False)
+            p = lambda x: isinstance(x, collections.Callable) and getattr(x, "handler", False)
             handlers = [v for k, v in getmembers(self, p)]
             for handler in handlers:
                 target = handler.target or getattr(self, "channel", "*")
@@ -84,7 +98,7 @@ class BaseComponent(Manager):
 
     def _unregisterHandlers(self, manager):
         for handler in self._handlers.copy():
-            manager.remove(handler)
+            manager.removeHandler(handler)
 
     def register(self, manager):
         """Register all Event Handlers with the given Manager
@@ -93,9 +107,9 @@ class BaseComponent(Manager):
         given Manager. By default, every Component (Base Component) is
         registered with itself.
         
-        Iif the Component or Manager being registered
+        If the Component or Manager being registered
         with is not the current Component, then any Hidden Components
-        in registered to this Component will also be regsitered with the
+        in registered to this Component will also be registered with the
         given Manager. A Registered Event will also be sent.
         """
 
@@ -126,15 +140,19 @@ class BaseComponent(Manager):
 
         return self
 
+    @handler('unregister')
+    def on_unregister(self, component=None):
+        if component == self or component == None:
+            self.unregister()
+
     def unregister(self):
         """Unregister all registered Event Handlers
         
         This will unregister all registered Event Handlers of this Component
-        from it's registered Component or Manager.
+        from its registered Component or Manager.
 
         @note: It's possible to unregister a Component from itself!
         """
-
         def _unregister(c, m, r):
             c._unregisterHandlers(m)
             c.root = self
@@ -161,25 +179,5 @@ class BaseComponent(Manager):
 
         return self
 
-class Component(BaseComponent):
+Component = HandlerMetaClass("Component", (BaseComponent,), {})
 
-    __metaclass__ = HandlersType
-
-    def __new__(cls, *args, **kwargs):
-        self = BaseComponent.__new__(cls, *args, **kwargs)
-        handlers = dict([(k, v) for k, v in cls.__dict__.items()
-                if getattr(v, "handler", False)])
-
-        overridden = lambda x: x in handlers and handlers[x].override
-
-        for base in cls.__bases__:
-            if issubclass(cls, base):
-                for k, v in base.__dict__.items():
-                    p1 = callable(v)
-                    p2 = getattr(v, "handler", False)
-                    p3 = overridden(k)
-                    if p1 and p2 and not p3:
-                        name = "%s_%s" % (base.__name__, k)
-                        method = MethodType(v, self)
-                        setattr(self, name, method)
-        return self
