@@ -4,28 +4,29 @@
 
 """
 Debugger component used to debug each event in a system by printing
-each event to sys.stderr or to a Logger Component instnace.
+each event to sys.stderr or to a Logger Component instance.
 """
 
 import os
 import sys
-from cStringIO import StringIO
 
-from handlers import handler
-from components import BaseComponent
+from io import BytesIO
+
+from .handlers import handler
+from .components import BaseComponent
 from circuits.tools import reprhandler
 
 class Debugger(BaseComponent):
     """Create a new Debugger Component
 
-    Creates a new Debugger Component that filters all events in teh system
+    Creates a new Debugger Component that filters all events in the system
     printing each event to sys.stderr or a Logger Component.
 
     :var IgnoreEvents: list of events (str) to ignore
     :var IgnoreChannels: list of channels (str) to ignore
     :var enabled: Enabled/Disabled flag
 
-    :param log: Logger Component instnace or None (*default*)
+    :param log: Logger Component instance or None (*default*)
     """
 
     IgnoreEvents = []
@@ -54,36 +55,35 @@ class Debugger(BaseComponent):
         self.IgnoreChannels.extend(kwargs.get("IgnoreChannels", []))
 
     @handler("exception", priority=100.0)
-    def _on_exception(self, type, value, traceback, handler=None):
+    def _on_exception(self, error_type, value, traceback, handler=None):
         if not self.errors:
             return
 
-        s = StringIO()
+        s = []
 
         if handler is None:
             handler = ""
         else:
             handler = reprhandler(self.root, handler)
 
-        s.write("ERROR %s(%s): %s\n" % ("%s " % handler, type, value))
-        s.write("%s\n" % "".join(traceback))
-
-        s.seek(0)
+        msg = "ERROR %s (%s): %s\n" % (handler, error_type, value)
+        s.append(msg)
+        s.extend(traceback)
+        s.append("\n")
 
         if self.logger is not None:
-            self.logger.error(s.getvalue())
+            self.logger.error("".join(s))
         else:
-            self.file.write(s.read())
-            self.file.flush()
-
-        s.close()
+            self.file.write("".join(s))
+            # Bugged on py2
+            #self.file.flush()
 
     @handler(priority=100.0)
     def _on_event(self, event, *args, **kwargs):
         """Global Event Handler
 
         Event handler to listen and filter all events printing each event
-        to self.file or a Logger Component instnace by calling self.logger.debug
+        to self.file or a Logger Component instance by calling self.logger.debug
         """
 
         if not self.events:
@@ -102,5 +102,6 @@ class Debugger(BaseComponent):
             if self.logger is not None:
                 self.logger.debug(s)
             else:
-                self.file.write("%s\n" % s)
+                self.file.write(s)
+                self.file.write("\n")
                 self.file.flush()
