@@ -7,57 +7,29 @@
 This module definse the Manager class subclasses by component.BaseComponent
 """
 
-import os
 from time import sleep
-from types import TupleType
-from threading import Thread
+from warnings import warn
 from collections import deque
 from inspect import getargspec
 from traceback import format_tb
 from sys import exc_info as _exc_info
+from signal import signal, SIGINT, SIGTERM
+from threading import current_thread, Thread
+from multiprocessing import current_process, Process
 
 try:
-    from threading import current_thread
+    from greenlet import getcurrent as getcurrent_greenlet, greenlet
+    GREENLET = True
 except ImportError:
-    from threading import currentThread as current_thread
+    GREENLET = False
 
-if os.name == "posix":
-    from signal import SIGHUP, SIGINT, SIGTERM
-    from signal import signal as _registerSignalHandler
-elif os.name in ["nt", "java"]:
-    from signal import SIGINT, SIGTERM
-    from signal import signal as _registerSignalHandler
-else:
-    raise RuntimeError("Unsupported platform '%s'" % os.name)
+from .values import Value
+from .events import Event, Started, Stopped, Signal
+from .events import Error, Success, Failure, Filter, Start, End
 
-try:
-    from multiprocessing import Process
-    from multiprocessing import current_process
-    HAS_MULTIPROCESSING = 2
-except:
-    try:
-        from processing import Process
-        from processing import currentProcess as current_process
-        HAS_MULTIPROCESSING = 1
-    except:
-        HAS_MULTIPROCESSING = 0
+TIMEOUT = 0.01  # 10ms timeout when no tick functions to process
 
 
-#
-# Compatibility and consistency fixes
-#
-
-if HAS_MULTIPROCESSING == 2:
-    setattr(Process, "isAlive", Process.is_alive)
-elif HAS_MULTIPROCESSING == 1:
-    setattr(Process, "pid", property(Process.getPid))
-
-from values import Value
-from events import Started, Stopped, Signal
-from events import Error, Success, Failure, Filter, Start, End
-
-TIMEOUT = 0.01 # 10ms timeout when no tick functions to process
-
 class Manager(object):
     """Manager
 
@@ -72,6 +44,7 @@ class Manager(object):
         "initializes x; see x.__class__.__doc__ for signature"
 
         self._globals = []
+        self._tasks = set()
         self._cmap = dict()
         self._tmap = dict()
         self._queue = deque()
@@ -83,6 +56,8 @@ class Manager(object):
         self._ticks = set()
 
         self._task = None
+        self._thread = None
+        self._proc = None
         self._bridge = None
         self._running = False
 
@@ -95,7 +70,7 @@ class Manager(object):
         name = self.__class__.__name__
 
         if hasattr(self, "channel") and self.channel is not None:
-            channel = "/%s" % self.channel 
+            channel = "/%s" % self.channel
         else:
             channel = ""
 
@@ -104,10 +79,7 @@ class Manager(object):
         h = len(self._handlers)
         state = self.state
 
-        if HAS_MULTIPROCESSING:
-            pid = current_process().pid
-        else:
-            pid = os.getpid()
+        pid = current_process().pid
 
         if pid:
             id = "%s:%s" % (pid, current_thread().getName())
@@ -146,7 +118,7 @@ class Manager(object):
 
         y.register(self)
         return self
-    
+
     def __iadd__(self, y):
         """x.__iadd__(y) <==> x += y
 
@@ -221,7 +193,7 @@ class Manager(object):
 
         # Any global channels
         handlers.extend(get(("*", channel), []))
- 
+
         # Any global channels for this target
         handlers.extend(get((channel, "*"), []))
 
@@ -326,7 +298,16 @@ class Manager(object):
                 if handler not in self._cmap[channel]:
                     self._cmap[channel].append(handler)
 
-    add = addHandler
+    def add(self, *args, **kwargs):
+        """Deprecated in 1.6
+
+        .. deprecated:: 1.6
+           Use :py:meth:`addHandler` instead.
+        """
+
+        warn(DeprecationWarning("Use .addHandler(...) instead"))
+
+        return self.addHandler(*args, **kwargs)
 
     def removeHandler(self, handler, channel=None):
         """Remove an Event Handler
@@ -342,7 +323,7 @@ class Manager(object):
         if channel is None:
             if handler in self._globals:
                 self._globals.remove(handler)
-            channels = self.channels.keys()
+            channels = list(self.channels.keys())
         else:
             channels = [channel]
 
@@ -360,17 +341,26 @@ class Manager(object):
 
             (target, channel) = channel
 
-            if target in self._tmap and handler in self._tmap:
+            if target in self._tmap and handler in self._tmap[target]:
                 self._tmap[target].remove(handler)
                 if not self._tmap[target]:
                     del self._tmap[target]
 
-            if channel in self._cmap and handler in self._cmap:
+            if channel in self._cmap and handler in self._cmap[channel]:
                 self._cmap[channel].remove(handler)
                 if not self._cmap[channel]:
                     del self._cmap[channel]
 
-    remove = removeHandler
+    def remove(self, *args, **kwargs):
+        """Deprecated in 1.6
+
+        .. deprecated:: 1.6
+           Use :py:meth:`removeHandler` instead.
+        """
+
+        warn(DeprecationWarning("Use .removeHandler(...) instead"))
+
+        self.removeHandler(*args, **kwargs)
 
     def _fire(self, event, channel):
         self._queue.append((event, channel))
@@ -398,7 +388,7 @@ class Manager(object):
         """
 
         if channel is None and target is None:
-            if type(event.channel) is TupleType:
+            if isinstance(event.channel, tuple):
                 target, channel = event.channel
             else:
                 channel = event.channel or event.name.lower()
@@ -422,36 +412,93 @@ class Manager(object):
 
         return event.value
 
-    fire = push = fireEvent
+    fire = fireEvent
+
+    def push(self, *args, **kwargs):
+        """Deprecated in 1.6
+
+        .. deprecated:: 1.6
+           Use :py:meth:`fire` instead.
+        """
+
+        warn(DeprecationWarning("Use .fire(...) instead"))
+
+        return self.fire(*args, **kwargs)
+
+    def registerTask(self, g):
+        self._tasks.add(g)
+
+    def unregisterTask(self, g):
+        self._tasks.remove(g)
+
+    def waitEvent(self, cls, limit=None):
+        if self._thread and self._thread != current_thread():
+            raise Exception("Cannot use .waitEvent from other thread")
+        if self._proc and self._proc != current_process():
+            raise Exception("Cannot use .waitEvent from other process")
+
+        g = getcurrent_greenlet()
+
+        is_instance = isinstance(cls, Event)
+        i = 0
+        e = None
+        caller = self._task
+
+        self.registerTask(g)
+        try:
+            while e != cls if is_instance else e.__class__ != cls:
+                if limit and i == limit or self._task is None:
+                    return
+                e, caller = caller.switch()
+                i += 1
+        finally:
+            self.unregisterTask(g)
+
+        return e
+
+    wait = waitEvent
+
+    def callEvent(self, event, channel=None, target=None):
+        self.fire(event, channel, target)
+        e = self.waitEvent(event)
+        return e.value
+
+    call = callEvent
 
     def _flush(self):
         q = self._queue
         self._queue = deque()
-        for event, channel in q:
-            self.__handleEvent(event, channel)
+
+        if GREENLET:
+            for event, channel in q:
+                dispatcher = greenlet(self._dispatcher)
+                dispatcher.switch(event, channel)
+        else:
+            for event, channel in q:
+                self._dispatcher(event, channel)
 
     def flushEvents(self):
-        """Flush all Events in the Event Queue
-
-        This will flush all Events in the Event Queue. If this Component's
-        Manager is itself, flush all Events from this Component's Event Queue,
-        otherwise, flush all Events from this Component's Manager's Event Queue.
-        """
+        """Flush all Events in the Event Queue"""
 
         self.root._flush()
 
     flush = flushEvents
 
-    def __handleEvent(self, event, channel):
+    def _dispatcher(self, event, channel):
         eargs = event.args
         ekwargs = event.kwargs
 
         retval = None
         handler = None
 
-        for handler in self._getHandlers(channel):
-            attrs = self._handlerattrs[handler]
+        handlers = self._getHandlers(channel)
+        handlerattrs = self._handlerattrs.copy()
+
+        for handler in handlers[:]:
+            error = None
             event.handler = handler
+            attrs = handlerattrs[handler]
+
             try:
                 if attrs["event"]:
                     retval = handler(event, *eargs, **ekwargs)
@@ -462,26 +509,33 @@ class Manager(object):
                 raise
             except:
                 etype, evalue, etraceback = _exc_info()
-                event.value.errors = True
                 traceback = format_tb(etraceback)
-                event.value.value = (etype, evalue, traceback)
+                error = (etype, evalue, traceback)
+
+                event.value.errors = True
+
+                event.value.value = error
+
                 if event.failure is not None:
-                    error = (etype, evalue, traceback)
                     self.fire(Failure(event, handler, error), *event.failure)
                 else:
                     self.fire(Error(etype, evalue, traceback, handler))
 
-            if retval is not None:
-                if retval and attrs["filter"]:
-                    if event.filter is not None:
-                        self.fire(Filter(event, handler, retval), *event.filter)
-                    return # Filter
-                if event.success is not None:
-                    self.fire(Success(event, handler, retval), *event.success)
+            if retval and attrs["filter"]:
+                if event.filter is not None:
+                    self.fire(Filter(event, handler, retval), *event.filter)
+                return  # Filter
+
+            if error is None and event.success is not None:
+                self.fire(Success(event, handler, retval), *event.success)
 
         if event.end is not None:
             self.fire(End(event, handler, retval), *event.end)
 
+        if GREENLET:
+            for task in self._tasks.copy():
+                task.switch(event, getcurrent_greenlet())
+
     def _signalHandler(self, signal, stack):
         self.fire(Signal(signal, stack))
         if signal in [SIGINT, SIGTERM]:
@@ -492,9 +546,10 @@ class Manager(object):
         target = self.run
         name = self.__class__.__name__
         mode = "P" if process else "T"
-        args = (log, mode,)
+        args = ()
+        kwargs = {'log': log, '__mode': mode}
 
-        if process and HAS_MULTIPROCESSING:
+        if process:
             if link is not None and isinstance(link, Manager):
                 from circuits.net.sockets import Pipe
                 from circuits.core.bridge import Bridge
@@ -503,54 +558,65 @@ class Manager(object):
                 parent, child = Pipe()
                 self._bridge = Bridge(root, socket=parent)
                 self._bridge.start()
-                args += (child,)
+                kwargs['__socket'] = child
 
-            self._task = Process(group, target, name, args)
-            self._task.daemon = True
+            self._proc = Process(group, target, name, args, kwargs)
+            self._proc.daemon = True
             self.tick()
-            self._task.start()
+            self._proc.start()
             return
 
-        self._task = Thread(group, target, name, args)
-        self._task.setDaemon(True)
-        self._task.start()
+        self._thread = Thread(group, target, name, args, kwargs)
+        self._thread.setDaemon(True)
+        self._thread.start()
 
     def stop(self):
         self._running = False
         self.fire(Stopped(self))
-        if (self._task and HAS_MULTIPROCESSING
-                and type(self._task) is Process
-                and self._task.isAlive()
-                and not current_process() == self._task):
-            self._task.terminate()
+        if self._proc and self._proc.is_alive() \
+                and not current_process() == self._proc:
+            self._proc.terminate()
         if (self._bridge is not None):
             self._bridge = None
+        self._process = None
+        self._thread = None
         self._task = None
         self.tick()
 
     def tick(self):
-        if self._ticks:
+        for f in self._ticks.copy():
             try:
-                [f() for f in self._ticks.copy()]
+                f()
             except (KeyboardInterrupt, SystemExit):
                 raise
             except:
                 etype, evalue, etraceback = _exc_info()
                 self.fire(Error(etype, evalue, format_tb(etraceback)))
+
+        if self:
+            self.flush()
         else:
-            sleep(TIMEOUT) # Nothing to do - Let's not tie up the CUP
+            sleep(TIMEOUT)
 
-        self._flush()
+    def run(self, *args, **kwargs):
+        log = kwargs.get("log", True)
+        __mode = kwargs.get("__mode", None)
+        __socket = kwargs.get("__socket", None)
 
-    def run(self, log=True, __mode=None, __socket=None):
+
+        if GREENLET:
+            self._task = greenlet(self._run)
+            self._task.switch(log, __mode, __socket)
+        else:
+            self._run(log, __mode, __socket)
+
+    def _run(self, log, __mode, __socket):
         if current_thread().getName() == "MainThread":
-            if os.name == "posix":
-                _registerSignalHandler(SIGHUP, self._signalHandler)
             try:
-                _registerSignalHandler(SIGINT, self._signalHandler)
-                _registerSignalHandler(SIGTERM, self._signalHandler)
+                signal(SIGINT,  self._signalHandler)
+                signal(SIGTERM, self._signalHandler)
             except ValueError:
-                pass # Ignore if we can't install signal handlers
+                pass  # Ignore if we can't install signal handlers
 
         if __socket is not None:
             from circuits.core.bridge import Bridge
@@ -568,7 +634,8 @@ class Manager(object):
                 self.tick()
         finally:
             if __socket is not None:
-                while bridge or manager: pass
+                while bridge or manager:
+                    self.tick()
                 manager.stop()
                 bridge.stop()
             self.stop()
