@@ -6,55 +6,38 @@
 
 This module contains Poller components that enable polling of file or socket
 descriptors for read/write events. Pollers:
-   - Select
-   - Poll
-   - EPoll
+- Select
+- Poll
+- EPoll
 """
 
-from errno import *
+import select
 from time import time
-from select import select
+from errno import EBADF, EINTR
 from select import error as SelectError
 from socket import error as SocketError
 
-try:
-    from select import poll
-    from select import POLLIN, POLLOUT, POLLHUP, POLLERR, POLLNVAL
-    HAS_POLL = 1
-except ImportError:
-    HAS_POLL = 0
+from .events import Event
+from .components import BaseComponent
 
-try:
-    from select import epoll
-    from select import EPOLLIN, EPOLLOUT, EPOLLHUP, EPOLLERR
-    HAS_EPOLL = 2
-except ImportError:
-    try:
-        from select26 import epoll
-        from select26 import EPOLLIN, EPOLLOUT, EPOLLHUP, EPOLLERR
-        HAS_EPOLL = 1
-    except ImportError:
-        HAS_EPOLL = 0
+TIMEOUT = 0.01  # 10ms timeout
 
-from events import Event
-from components import BaseComponent
 
-if HAS_POLL:
-    _POLL_DISCONNECTED = (POLLHUP | POLLERR | POLLNVAL)
+class Read(Event):
+    """Read Event"""
 
-if HAS_EPOLL:
-    _EPOLL_DISCONNECTED = (EPOLLHUP | EPOLLERR)
 
-TIMEOUT = 0.2
+class Write(Event):
+    """Write Event"""
 
-###
-### Events
-###
 
-class Read(Event): pass
-class Write(Event): pass
-class Error(Event): pass
-class Disconnect(Event): pass
+class Error(Event):
+    """Error Event"""
+
+
+class Disconnect(Event):
+    """Disconnect Event"""
+
 
 class BasePoller(BaseComponent):
 
@@ -108,6 +91,7 @@ class BasePoller(BaseComponent):
     def getTarget(self, fd):
         return self._targets.get(fd, self.manager)
 
+
 class Select(BasePoller):
     """Select(...) -> new Select Poller Component
 
@@ -129,46 +113,33 @@ class Select(BasePoller):
         for socks in (self._read[:], self._write[:]):
             for sock in socks:
                 try:
-                    select([sock], [sock], [sock], 0)
-                except Exception, e:
+                    select.select([sock], [sock], [sock], 0)
+                except Exception:
                     self.discard(sock)
 
     def __tick__(self):
         try:
             if not any([self._read, self._write]):
                 return
-            r, w, _ = select(self._read, self._write, [], self.timeout)
-            if r or w:
-                self.timeout = 0.0
-            dtime = time() - self._ts
-            self._ts = time()
-            if not dtime == 0.0:
-                load = float(len(r) + len(w)) / dtime
-                if load > self._load:
-                    if self.timeout > 0.1:
-                        self.timeout -= 0.001
-                else:
-                    if self.timeout < 0.5:
-                        self.timeout += 0.001
-                self._load = load
-        except ValueError, e:
+            r, w, _ = select.select(self._read, self._write, [], self.timeout)
+        except ValueError as e:
             # Possibly a file descriptor has gone negative?
             return self._preenDescriptors()
-        except TypeError, e:
+        except TypeError as e:
             # Something *totally* invalid (object w/o fileno, non-integral
             # result) was passed
             return self._preenDescriptors()
-        except (SelectError, SocketError, IOError), e:
+        except (SelectError, SocketError, IOError) as e:
             # select(2) encountered an error
-            if e[0] in (0, 2):
+            if e.args[0] in (0, 2):
                 # windows does this if it got an empty list
                 if (not self._read) and (not self._write):
                     return
                 else:
                     raise
-            elif e[0] == EINTR:
+            elif e.args[0] == EINTR:
                 return
-            elif e[0] == EBADF:
+            elif e.args[0] == EBADF:
                 return self._preenDescriptors()
             else:
                 # OK, I really don't know what's going on.  Blow up.
@@ -177,11 +148,12 @@ class Select(BasePoller):
         for sock in w:
             if self.isWriting(sock):
                 self.push(Write(sock), "_write", self.getTarget(sock))
-            
+
         for sock in r:
             if self.isReading(sock):
                 self.push(Read(sock), "_read", self.getTarget(sock))
 
+
 class Poll(BasePoller):
     """Poll(...) -> new Poll Poller Component
 
@@ -195,7 +167,12 @@ class Poll(BasePoller):
         super(Poll, self).__init__(timeout, channel=channel)
 
         self._map = {}
-        self._poller = poll()
+        self._poller = select.poll()
+
+        self._disconnected_flag = (select.POLLHUP
+                | select.POLLERR
+                | select.POLLNVAL
+        )
 
     def _updateRegistration(self, fd):
         fileno = fd.fileno()
@@ -208,9 +185,9 @@ class Poll(BasePoller):
         mask = 0
 
         if fd in self._read:
-            mask = mask | POLLIN
+            mask = mask | select.POLLIN
         if fd in self._write:
-            mask = mask | POLLOUT
+            mask = mask | select.POLLOUT
 
         if mask:
             self._poller.register(fd, mask)
@@ -242,8 +219,8 @@ class Poll(BasePoller):
     def __tick__(self):
         try:
             l = self._poller.poll(self.timeout)
-        except SelectError, e:
-            if e[0] == EINTR:
+        except SelectError as e:
+            if e.args[0] == EINTR:
                 return
             else:
                 raise
@@ -257,24 +234,25 @@ class Poll(BasePoller):
 
         fd = self._map[fileno]
 
-        if event & _POLL_DISCONNECTED and not (event & POLLIN):
+        if event & self._disconnected_flag and not (event & select.POLLIN):
             self.push(Disconnect(fd), "_disconnect", self.getTarget(fd))
             self._poller.unregister(fileno)
             super(Poll, self).discard(fd)
             del self._map[fileno]
         else:
             try:
-                if event & POLLIN:
+                if event & select.POLLIN:
                     self.push(Read(fd), "_read", self.getTarget(fd))
-                if event & POLLOUT:
+                if event & select.POLLOUT:
                     self.push(Write(fd), "_write", self.getTarget(fd))
-            except Exception, e:
+            except Exception as e:
                 self.push(Error(fd, e), "_error", self.getTarget(fd))
                 self.push(Disconnect(fd), "_disconnect", self.getTarget(fd))
                 self._poller.unregister(fileno)
                 super(Poll, self).discard(fd)
                 del self._map[fileno]
 
+
 class EPoll(BasePoller):
     """EPoll(...) -> new EPoll Poller Component
 
@@ -288,24 +266,26 @@ class EPoll(BasePoller):
         super(EPoll, self).__init__(timeout, channel=channel)
 
         self._map = {}
-        self._poller = epoll()
+        self._poller = select.epoll()
+
+        self._disconnected_flag = (select.EPOLLHUP | select.EPOLLERR)
 
     def _updateRegistration(self, fd):
         try:
             fileno = fd.fileno()
             self._poller.unregister(fileno)
-        except (SocketError, IOError), e:
-            if e[0] == EBADF:
-                keys = [k for k, v in self._map.items() if v == fd]
+        except (SocketError, IOError) as e:
+            if e.args[0] == EBADF:
+                keys = [k for k, v in list(self._map.items()) if v == fd]
                 for key in keys:
                     del self._map[key]
 
         mask = 0
 
         if fd in self._read:
-            mask = mask | EPOLLIN
+            mask = mask | select.EPOLLIN
         if fd in self._write:
-            mask = mask | EPOLLOUT
+            mask = mask | select.EPOLLOUT
 
         if mask:
             self._poller.register(fd, mask)
@@ -336,11 +316,11 @@ class EPoll(BasePoller):
     def __tick__(self):
         try:
             l = self._poller.poll(self.timeout)
-        except IOError, e:
-            if e[0] == EINTR:
+        except IOError as e:
+            if e.args[0] == EINTR:
                 return
-        except SelectError, e:
-            if e[0] == EINTR:
+        except SelectError as e:
+            if e.args[0] == EINTR:
                 return
             else:
                 raise
@@ -354,30 +334,100 @@ class EPoll(BasePoller):
 
         fd = self._map[fileno]
 
-        if event & _EPOLL_DISCONNECTED and not (event & POLLIN):
+        if event & self._disconnected_flag and not (event & select.POLLIN):
             self.push(Disconnect(fd), "_disconnect", self.getTarget(fd))
             self._poller.unregister(fileno)
             super(EPoll, self).discard(fd)
             del self._map[fileno]
         else:
             try:
-                if event & EPOLLIN:
+                if event & select.EPOLLIN:
                     self.push(Read(fd), "_read", self.getTarget(fd))
-                if event & EPOLLOUT:
+                if event & select.EPOLLOUT:
                     self.push(Write(fd), "_write", self.getTarget(fd))
-            except Exception, e:
+            except Exception as e:
                 self.push(Error(fd, e), "_error", self.getTarget(fd))
                 self.push(Disconnect(fd), "_disconnect", self.getTarget(fd))
                 self._poller.unregister(fileno)
                 super(EPoll, self).discard(fd)
                 del self._map[fileno]
 
-### FIXME: The EPoll poller has some weird performance issues :/
-#if HAS_EPOLL:
-#    Poller = EPoll
-#else:
-#    Poller = Select
+
+class KQueue(BasePoller):
+    """KQueue(...) -> new KQueue Poller Component
+
+    Creates a new KQueue Poller Component that uses the kqueue poller
+    implementation.
+    """
+
+    channel = "kqueue"
+
+    def __init__(self, timeout=0.00001, channel=channel):
+        super(KQueue, self).__init__(timeout, channel=channel)
+        self._map = {}
+        self._poller = select.kqueue()
+
+    def addReader(self, source, sock):
+        super(KQueue, self).addReader(source, sock)
+        self._map[sock.fileno()] = sock
+        self._poller.control([select.kevent(sock,
+            select.KQ_FILTER_READ, select.KQ_EV_ADD)], 0)
+
+    def addWriter(self, source, sock):
+        super(KQueue, self).addWriter(source, sock)
+        self._map[sock.fileno()] = sock
+        self._poller.control([select.kevent(sock,
+            select.KQ_FILTER_WRITE, select.KQ_EV_ADD)], 0)
+
+    def removeReader(self, sock):
+        super(KQueue, self).removeReader(sock)
+        self._poller.control([select.kevent(sock,
+            select.KQ_FILTER_READ, select.KQ_EV_DELETE)], 0)
+
+    def removeWriter(self, sock):
+        super(KQueue, self).removeWriter(sock)
+        self._poller.control([select.kevent(sock,
+            select.KQ_FILTER_WRITE, select.KQ_EV_DELETE)], 0)
+
+    def discard(self, sock):
+        super(KQueue, self).discard(sock)
+        del self._map[sock.fileno()]
+        self._poller.control([select.kevent(sock,
+            select.KQ_FILTER_WRITE | select.KQ_FILTER_READ,
+            select.KQ_EV_DELETE)], 0)
+
+    def __tick__(self):
+        try:
+            l = self._poller.control(None, 1000, self.timeout)
+        except SelectError as e:
+            if e[0] == EINTR:
+                return
+            else:
+                raise
+
+        for event in l:
+            self._process(event)
+
+    def _process(self, event):
+        if event.ident not in self._map:
+            # shouldn't happen ?
+            # we unregister the socket since we don't care about it anymore
+            self._poller.control(
+                [select.kevent(event.ident, event.filter,
+                    select.KQ_EV_DELETE)], 0)
+            return
+
+        sock = self._map[event.ident]
+
+        if event.flags & select.KQ_EV_ERROR:
+            self.push(Error(sock, "error"), "_error", self.getTarget(sock))
+        elif event.flags & select.KQ_EV_EOF:
+            self.push(Disconnect(sock), "_disconnect", self.getTarget(sock))
+        elif event.filter == select.KQ_FILTER_WRITE:
+            self.push(Write(sock), "_write", self.getTarget(sock))
+        elif event.filter == select.KQ_FILTER_READ:
+            self.push(Read(sock), "_read", self.getTarget(sock))
 
 Poller = Select
 
-__all__ = ("BasePoller", "Poller", "Select", "Poll", "EPoll",)
+__all__ = ("BasePoller", "Poller", "Select", "Poll", "EPoll", "KQueue")
