@@ -7,16 +7,14 @@
 This defines the Value object used by components and events.
 """
 
-from types import ListType
-from itertools import imap
 
-from events import Event
+from .events import Event
 
 class ValueChanged(Event):
     """Value Changed Event
 
     This Event is triggered when the return Value of an Event Handler has
-    changed it's value.
+    changed its value.
     """
 
     def __init__(self, value):
@@ -59,6 +57,7 @@ class Value(object):
         self.errors = False
         self._parent = self
         self._value = None
+        self.handled = False
 
     def __getstate__(self):
         keys = ("event", "onSet", "result", "errors", "_value")
@@ -66,7 +65,7 @@ class Value(object):
 
     def __contains__(self, y):
         value = self.value
-        return y in value if type(value) is ListType else y == value
+        return y in value if isinstance(value, list) else y == value
 
     def __getitem__(self, y):
         v = self.value[y]
@@ -76,8 +75,8 @@ class Value(object):
             return v
 
     def __iter__(self):
-        return imap(lambda v: v.value if isinstance(v, Value) else v,
-                self.value)
+        return iter(map(lambda v: v.value if isinstance(v, Value) else v,
+                self.value))
 
     def __repr__(self):
         "x.__repr__() <==> repr(x)"
@@ -104,7 +103,7 @@ class Value(object):
         if isinstance(value, Value):
             value._parent = self
 
-        if self.result and type(self._value) is ListType:
+        if self.result and isinstance(self._value, list):
             self._value.append(value)
         elif self.result:
             self._value = [self._value]
