@@ -8,11 +8,16 @@ Worker components used to perform "work" in independent threads or
 processes. Worker(s) are typically used by a Pool (circuits.core.pools)
 to create a pool of workers. Worker(s) are not registered with a Manager
 or another Component - instead they are managed by the Pool. If a Worker
-is used independently it should not be registered as it causes it's
+is used independently it should not be registered as it causes its
 main event handler ``_on_task`` to execute in the other thread blocking it.
 """
 
-from circuits.core import handler, BaseComponent, Event
+from .events import Event
+from .bridge import Bridge
+from .utils import findroot
+from .manager import Manager
+from .handlers import handler
+from .components import BaseComponent
 
 
 class Task(Event):
@@ -38,6 +43,15 @@ class Task(Event):
 
 
 class Worker(BaseComponent):
+    """A thread/process Worker Component
+
+    This Component creates a Worker (either a thread or process) which
+    when given a ``Task``, will execute the given function in the task
+    in the background in its thread/process.
+
+    :param process: True to start this Worker as a process (Thread otherwise)
+    :type process: bool
+    """
 
     channel = "worker"
 
