@@ -7,5 +7,5 @@
 This package contains components that implement various networking protocols.
 """
 
-from line import LP
-from irc import IRC
+from .line import LP
+from .irc import IRC
