@@ -11,16 +11,16 @@ import os
 from collections import defaultdict, deque
 
 from errno import EAGAIN, EALREADY, EBADF
-from errno import ECONNABORTED, EINPROGRESS, EISCONN, EMFILE, ENFILE
+from errno import ECONNABORTED, EINPROGRESS, EINTR, EISCONN, EMFILE, ENFILE
 from errno import ENOBUFS, ENOMEM, ENOTCONN, EPERM, EPIPE, EINVAL, EWOULDBLOCK
 
 from _socket import socket as SocketType
 
 from socket import gaierror, error as SocketError
-from socket import gethostname, gethostbyname, socket, socketpair
+from socket import gethostname, gethostbyname, socket
 
+from socket import AF_INET, IPPROTO_TCP, SOCK_STREAM, SOCK_DGRAM
 from socket import SOL_SOCKET, SO_BROADCAST, SO_REUSEADDR, TCP_NODELAY
-from socket import AF_INET, AF_UNIX, IPPROTO_TCP, SOCK_STREAM, SOCK_DGRAM
 
 try:
     from ssl import wrap_socket as ssl_socket
@@ -31,29 +31,33 @@ except ImportError:
     warnings.warn("No SSL support available.")
     HAS_SSL = 0
 
+
 from circuits.core.utils import findcmp
 from circuits.core import handler, Event, Component
 from circuits.core.pollers import BasePoller, Poller
 
-BUFSIZE = 4096 # 4KB Buffer
-BACKLOG = 5000 #  5K Concurrent Connections
+BUFSIZE = 4096  # 4KB Buffer
+BACKLOG = 5000  # 5K Concurrent Connections
 
 ###
 ### Event Objects
 ###
 
+
 class Connect(Event):
     """Connect Event
-
+    
     This Event is sent when a new client connection has arrived on a server.
     This event is also used for client's to initiate a new connection to
     a remote host.
-
-    @note: This event is used for both Client and Server Components.
-
+    
+    .. note ::
+       
+       This event is used for both Client and Server Components.
+    
     :param args:  Client: (host, port) Server: (sock, host, port)
     :type  args: tuple
-
+    
     :param kwargs: Client: (ssl)
     :type  kwargs: dict
     """
@@ -63,6 +67,7 @@ class Connect(Event):
 
         super(Connect, self).__init__(*args, **kwargs)
 
+
 class Disconnect(Event):
     """Disconnect Event
 
@@ -80,6 +85,7 @@ class Disconnect(Event):
 
         super(Disconnect, self).__init__(*args)
 
+
 class Connected(Event):
     """Connected Event
 
@@ -99,6 +105,7 @@ class Connected(Event):
 
         super(Connected, self).__init__(host, port)
 
+
 class Disconnected(Event):
     """Disconnected Event
 
@@ -112,6 +119,7 @@ class Disconnected(Event):
 
         super(Disconnected, self).__init__()
 
+
 class Read(Event):
     """Read Event
 
@@ -128,6 +136,7 @@ class Read(Event):
 
         super(Read, self).__init__(*args)
 
+
 class Error(Event):
     """Error Event
 
@@ -144,6 +153,7 @@ class Error(Event):
 
         super(Error, self).__init__(*args)
 
+
 class Write(Event):
     """Write Event
 
@@ -181,6 +191,7 @@ class Close(Event):
 
         super(Close, self).__init__(*args)
 
+
 class Ready(Event):
     """Ready Event
 
@@ -201,10 +212,11 @@ class Ready(Event):
 
         super(Ready, self).__init__(component)
 
+
 class Closed(Event):
     """Closed Event
 
-    This Event is sent when a server has closed it's listening socket.
+    This Event is sent when a server has closed its listening socket.
 
     @note: This event is for Server components.
     """
@@ -218,45 +230,46 @@ class Closed(Event):
 ### Components
 ###
 
+
 class Client(Component):
 
     channel = "client"
 
-    def __init__(self, bind=None, **kwargs):
-        channel = kwargs.get("channel", self.__class__.channel)
+    def __init__(self, bind=None, bufsize=BUFSIZE,
+            channel=channel):
         super(Client, self).__init__(channel=channel)
 
-        self.encoding = kwargs.get("encoding", "utf-8")
-
-        if type(bind) is int:
+        if isinstance(bind, int):
             try:
-                self.bind = (gethostbyname(gethostname()), bind)
+                self._bind = (gethostbyname(gethostname()), bind)
             except gaierror:
-                self.bind = ("0.0.0.0", bind)
-        elif type(bind) is str and ":" in bind:
+                self._bind = ("0.0.0.0", bind)
+        elif isinstance(bind, str) and ":" in bind:
             host, port = bind.split(":")
             port = int(port)
-            self.bind = (host, port)
+            self._bind = (host, port)
         else:
-            self.bind = bind
+            self._bind = None
+        if isinstance(bind, SocketType):
+            self._sock = bind
+        else:
+            self._sock = self._create_socket()
 
-        self.host = "0.0.0.0"
-        self.port = 0
-        self.secure  = False
+        self._bufsize = bufsize
 
-        self.server = {}
-        self.issuer = {}
-
-        self._bufsize = kwargs.get("bufsize", BUFSIZE)
-
-        self._poller = None
-
-        self._sock = None
         self._ssock = None
+        self._poller = None
         self._buffer = deque()
         self._closeflag = False
         self._connected = False
 
+        self.host = "0.0.0.0"
+        self.port = 0
+        self.secure = False
+
+        self.server = {}
+        self.issuer = {}
+
     @property
     def connected(self):
         return getattr(self, "_connected", None)
@@ -288,6 +301,9 @@ class Client(Component):
         self.push(Close(), "close", self.channel)
 
     def _close(self):
+        if not self._connected:
+            return
+
         self._poller.discard(self._sock)
 
         self._buffer.clear()
@@ -319,8 +335,8 @@ class Client(Component):
                 self.push(Read(data), "read", self.channel)
             else:
                 self.close()
-        except SocketError, e:
-            if e[0] == EWOULDBLOCK:
+        except SocketError as e:
+            if e.args[0] == EWOULDBLOCK:
                 return
             else:
                 self.push(Error(e), "error", self.channel)
@@ -328,18 +344,15 @@ class Client(Component):
 
     def _write(self, data):
         try:
-            if type(data) is unicode:
-                data = data.encode(self.encoding)
-
             if self.secure and self._ssock:
-                bytes = self._ssock.write(data)
+                nbytes = self._ssock.write(data)
             else:
-                bytes = self._sock.send(data)
+                nbytes = self._sock.send(data)
 
-            if bytes < len(data):
-                self._buffer.appendleft(data[bytes:])
-        except SocketError, e:
-            if e[0] in (EPIPE, ENOTCONN):
+            if nbytes < len(data):
+                self._buffer.appendleft(data[nbytes:])
+        except SocketError as e:
+            if e.args[0] in (EPIPE, ENOTCONN):
                 self._close()
             else:
                 self.push(Error(e), "error", self.channel)
@@ -369,20 +382,13 @@ class Client(Component):
             elif self._poller.isWriting(self._sock):
                 self._poller.removeWriter(self._sock)
 
+
 class TCPClient(Client):
 
-    def __init__(self, bind=None, **kwargs):
-        super(TCPClient, self).__init__(bind, **kwargs)
-
-        if type(bind) is SocketType:
-            self._sock = bind
-        else:
-            self._sock = self._create_socket()
-
     def _create_socket(self):
         sock = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP)
-        if self.bind is not None:
-            sock.bind((self.bind, 0))
+        if self._bind is not None:
+            sock.bind(self._bind)
 
         sock.setblocking(False)
         sock.setsockopt(IPPROTO_TCP, TCP_NODELAY, 1)
@@ -392,20 +398,20 @@ class TCPClient(Client):
     def connect(self, host, port, secure=False, **kwargs):
         self.host = host
         self.port = port
-        self.secure  = secure
+        self.secure = secure
 
         if self.secure:
             self.certfile = kwargs.get("certfile", None)
             self.keyfile = kwargs.get("keyfile", None)
 
         try:
-            r = self._sock.connect_ex((host, port))
-        except SocketError, e:
-            if e[0] in (EBADF, EINVAL,):
+            r = self._sock.connect((host, port))
+        except SocketError as e:
+            if e.args[0] in (EBADF, EINVAL,):
                 self._sock = self._create_socket()
                 r = self._sock.connect_ex((host, port))
             else:
-                r = e[0]
+                r = e.args[0]
 
         if r:
             if r in (EISCONN, EWOULDBLOCK, EINPROGRESS, EALREADY):
@@ -423,20 +429,15 @@ class TCPClient(Client):
 
         self.push(Connected(host, port), "connected", self.channel)
 
+
 class UNIXClient(Client):
 
-    def __init__(self, bind=None, **kwargs):
-        super(UNIXClient, self).__init__(bind, **kwargs)
-
-        if type(bind) is SocketType:
-            self._sock = bind
-        else:
-            self._sock = self._create_socket()
-
     def _create_socket(self):
+        from socket import AF_UNIX
+
         sock = socket(AF_UNIX, SOCK_STREAM)
-        if self.bind is not None:
-            sock.bind(self.bind)
+        if self._bind is not None:
+            sock.bind(self._bind)
 
         sock.setblocking(False)
 
@@ -444,6 +445,9 @@ class UNIXClient(Client):
 
     @handler("registered", target="*")
     def _on_registered(self, component, manager):
+        pass
+
+    def ready(self, component):
         if self._poller is not None and self._connected:
             self._poller.addReader(self, self._sock)
 
@@ -457,8 +461,8 @@ class UNIXClient(Client):
 
         try:
             r = self._sock.connect_ex(path)
-        except SocketError, e:
-            r = e[0]
+        except SocketError as e:
+            r = e.args[0]
 
         if r:
             if r in (EISCONN, EWOULDBLOCK, EINPROGRESS, EALREADY):
@@ -481,23 +485,34 @@ class Server(Component):
 
     channel = "server"
 
-    def __init__(self, bind, secure=False, **kwargs):
-        channel = kwargs.get("channel", self.__class__.channel)
+    def __init__(self, bind, secure=False, backlog=BACKLOG,
+            bufsize=BUFSIZE, channel=channel, **kwargs):
         super(Server, self).__init__(channel=channel)
 
-        self.encoding = kwargs.get("encoding", "utf-8")
-
         if type(bind) is int:
             try:
-                self.bind = (gethostbyname(gethostname()), bind)
+                self._bind = (gethostbyname(gethostname()), bind)
             except gaierror:
-                self.bind = ("0.0.0.0", bind)
+                self._bind = ("0.0.0.0", bind)
         elif type(bind) is str and ":" in bind:
             host, port = bind.split(":")
             port = int(port)
-            self.bind = (host, port)
+            self._bind = (host, port)
         else:
-            self.bind = bind
+            self._bind = bind
+
+        self._backlog = backlog
+        self._bufsize = bufsize
+
+        if isinstance(bind, socket):
+            self._sock = bind
+        else:
+            self._sock = self._create_socket()
+
+        self._closeq = []
+        self._clients = []
+        self._poller = None
+        self._buffers = defaultdict(deque)
 
         self.secure = secure
 
@@ -508,16 +523,6 @@ class Server(Component):
             self.ssl_version = kwargs.get("ssl_version", PROTOCOL_SSLv23)
             self.ca_certs = kwargs.get("ca_certs", None)
 
-        self._bufsize = kwargs.get("bufsize", BUFSIZE)
-        self._backlog = kwargs.get("backlog", BACKLOG)
-
-        self._poller = None
-
-        self._sock = None
-        self._buffers = defaultdict(deque)
-        self._closeq = []
-        self._clients = []
-
     @property
     def connected(self):
         return True
@@ -525,12 +530,18 @@ class Server(Component):
     @property
     def host(self):
         if hasattr(self, "_sock"):
-            return self._sock.getsockname()[0]
+            sockname = self._sock.getsockname()
+            if isinstance(sockname, tuple):
+                return sockname[0]
+            else:
+                return sockname
 
     @property
     def port(self):
         if hasattr(self, "_sock"):
-            return self._sock.getsockname()[1]
+            sockname = self._sock.getsockname()
+            if isinstance(sockname, tuple):
+                return sockname[1]
 
     @handler("registered", target="*")
     def _on_registered(self, component, manager):
@@ -563,6 +574,8 @@ class Server(Component):
         self.push(Close(), "close", self.channel)
 
     def _close(self, sock):
+        if sock is None:
+            return
         if not sock == self._sock and sock not in self._clients:
             return
 
@@ -573,6 +586,8 @@ class Server(Component):
 
         if sock in self._clients:
             self._clients.remove(sock)
+        else:
+            self._sock = None
 
         try:
             sock.shutdown(2)
@@ -610,8 +625,8 @@ class Server(Component):
                 self.push(Read(sock, data), "read", self.channel)
             else:
                 self.close(sock)
-        except SocketError, e:
-            if e[0] == EWOULDBLOCK:
+        except SocketError as e:
+            if e.args[0] == EWOULDBLOCK:
                 return
             else:
                 self.push(Error(sock, e), "error", self.channel)
@@ -622,17 +637,15 @@ class Server(Component):
             return
 
         try:
-            if type(data) is unicode:
-                data = data.encode(self.encoding)
-
-            bytes = sock.send(data)
-            if bytes < len(data):
-                self._buffers[sock].appendleft(data[bytes:])
-        except SocketError, e:
-            if e[0] in (EPIPE, ENOTCONN):
+            nbytes = sock.send(data)
+            if nbytes < len(data):
+                self._buffers[sock].appendleft(data[nbytes:])
+        except SocketError as e:
+            if e.args[0] not in (EINTR, EWOULDBLOCK, ENOBUFS):
+                self.push(Error(sock, e), "error", self.channel)
                 self._close(sock)
             else:
-                self.push(Error(sock, e), "error", self.channel)
+                self._buffers[sock].appendleft(data)
 
     def write(self, sock, data):
         if not self._poller.isWriting(sock):
@@ -655,18 +668,18 @@ class Server(Component):
                     ssl_version=self.ssl_version,
                     ca_certs=self.ca_certs)
 
-        except SSLError, e:
+        except SSLError as e:
             raise
 
-        except SocketError, e:
-            if e[0] in (EWOULDBLOCK, EAGAIN):
+        except SocketError as  e:
+            if e.args[0] in (EWOULDBLOCK, EAGAIN):
                 return
-            elif e[0] == EPERM:
+            elif e.args[0] == EPERM:
                 # Netfilter on Linux may have rejected the
                 # connection, but we get told to try to accept()
                 # anyway.
                 return
-            elif e[0] in (EMFILE, ENOBUFS, ENFILE, ENOMEM, ECONNABORTED):
+            elif e.args[0] in (EMFILE, ENOBUFS, ENFILE, ENOMEM, ECONNABORTED):
                 # Linux gives EMFILE when a process is not allowed
                 # to allocate any more file descriptors.  *BSD and
                 # Win32 give (WSA)ENOBUFS.  Linux can also give
@@ -713,44 +726,31 @@ class Server(Component):
             elif self._poller.isWriting(sock):
                 self._poller.removeWriter(sock)
 
+
 class TCPServer(Server):
 
-    def __init__(self, bind, secure=False, **kwargs):
-        super(TCPServer, self).__init__(bind, secure, **kwargs)
-
-        if type(bind) is SocketType:
-            self.bind = None
-            self._sock = bind
-        else:
-            self._sock = self._create_socket()
-
     def _create_socket(self):
         sock = socket(AF_INET, SOCK_STREAM)
 
         sock.setsockopt(SOL_SOCKET, SO_REUSEADDR, 1)
         sock.setsockopt(IPPROTO_TCP, TCP_NODELAY, 1)
         sock.setblocking(False)
-        sock.bind(self.bind)
+        sock.bind(self._bind)
         sock.listen(self._backlog)
 
         return sock
 
+
 class UNIXServer(Server):
 
-    def __init__(self, bind, secure=False, **kwargs):
-        super(UNIXServer, self).__init__(bind, secure, **kwargs)
-
-        if type(bind) is SocketType:
-            self._sock = bind
-        else:
-            self._sock = self._create_socket()
-
     def _create_socket(self):
-        if os.path.exists(self.bind):
-            os.unlink(self.bind)
+        from socket import AF_UNIX
+
+        if os.path.exists(self._bind):
+            os.unlink(self._bind)
 
         sock = socket(AF_UNIX, SOCK_STREAM)
-        sock.bind(self.bind)
+        sock.bind(self._bind)
 
         sock.setsockopt(SOL_SOCKET, SO_REUSEADDR, 1)
         sock.setblocking(False)
@@ -758,26 +758,17 @@ class UNIXServer(Server):
 
         return sock
 
-    @property
-    def host(self):
-        if hasattr(self, "bind"):
-            return self.bind
 
 class UDPServer(Server):
 
-    def __init__(self, bind, secure=False, **kwargs):
-        super(UDPServer, self).__init__(bind, secure, **kwargs)
-
-        if type(bind) is SocketType:
-            self._sock = bind
-        else:
-            self._sock = self._create_socket()
-
     def _create_socket(self):
         sock = socket(AF_INET, SOCK_DGRAM)
-        sock.bind(self.bind)
+
+        sock.bind(self._bind)
 
         sock.setsockopt(SOL_SOCKET, SO_BROADCAST, 1)
+        sock.setsockopt(SOL_SOCKET, SO_REUSEADDR, 1)
+
         sock.setblocking(False)
 
         return sock
@@ -790,6 +781,9 @@ class UDPServer(Server):
 
         try:
             sock.shutdown(2)
+        except SocketError:
+            pass
+        try:
             sock.close()
         except SocketError:
             pass
@@ -798,30 +792,31 @@ class UDPServer(Server):
 
     @handler("close", override=True)
     def close(self):
-        if self._sock not in self._closeq:
+        self.push(Closed(), "closed", self.channel)
+
+        if self._buffers[self._sock] and self._sock not in self._closeq:
             self._closeq.append(self._sock)
+        else:
+            self._close(self._sock)
 
     def _read(self):
         try:
             data, address = self._sock.recvfrom(self._bufsize)
             if data:
                 self.push(Read(address, data), "read", self.channel)
-        except SocketError, e:
-            if e[0] in (EWOULDBLOCK, EAGAIN):
+        except SocketError as e:
+            if e.args[0] in (EWOULDBLOCK, EAGAIN):
                 return
             self.push(Error(self._sock, e), "error", self.channel)
             self._close(self._sock)
 
     def _write(self, address, data):
         try:
-            if type(data) is unicode:
-                data = data.encode(self.encoding)
-
             bytes = self._sock.sendto(data, address)
             if bytes < len(data):
                 self._buffers[self._sock].appendleft(data[bytes:])
-        except SocketError, e:
-            if e[0] in (EPIPE, ENOTCONN):
+        except SocketError as e:
+            if e.args[0] in (EPIPE, ENOTCONN):
                 self._close(self._sock)
             else:
                 self.push(Error(self._sock, e), "error", self.channel)
@@ -832,6 +827,7 @@ class UDPServer(Server):
             self._poller.addWriter(self, self._sock)
         self._buffers[self._sock].append((address, data))
 
+    @handler("broadcast", override=True)
     def broadcast(self, data, port):
         self.write(("<broadcast>", port), data)
 
@@ -858,6 +854,7 @@ class UDPServer(Server):
 
 UDPClient = UDPServer
 
+
 def Pipe(*channels, **kwargs):
     """Create a new full duplex Pipe
 
@@ -865,6 +862,8 @@ def Pipe(*channels, **kwargs):
     the pipe.
     """
 
+    from socket import socketpair
+
     if not channels:
         channels = ("a", "b")
 
