@@ -11,8 +11,11 @@ tools are installed as executables with a prefix of "circuits."
 from hashlib import md5
 from warnings import warn
 
+from circuits.core.events import Unregister
 
 def tryimport(modules, message=None):
+    if isinstance(modules, str):
+        modules = (modules,)
     for module in modules:
         try:
             return __import__(module, globals(), locals())
@@ -72,9 +75,11 @@ def graph(x, name=None):
     """
 
     def getname(c):
-        return "%s-%s" % (c.name, md5(str(hash(c))).hexdigest()[-4:])
+        s = "%d" % id(c)
+        h = md5(s.encode("utf-8")).hexdigest()[-4:]
+        return "%s-%s" % (c.name, h)
 
-    pydot = tryimport(("pydot",))
+    pydot = tryimport("pydot")
     if pydot is not None:
         graph_edges = []
         for (u, v) in edges(x):
