@@ -16,6 +16,11 @@ from circuits.web.errors import HTTPError
 from circuits.web.controllers import BaseController
 from circuits.web.utils import parseQueryString, dictform
 
+from circuits.web.events import Response
+from circuits.web.errors import HTTPError
+from circuits.web.controllers import BaseController
+from circuits.web.tools import expires, serve_file
+from circuits.web.utils import parseQueryString, dictform
 
 class Dispatcher(BaseComponent):
 
@@ -38,7 +43,7 @@ class Dispatcher(BaseComponent):
                 headers=headers,
                 environ={"REQUEST_METHOD": "POST"},
                 keep_blank_values=True)
-        except Exception, e:
+        except Exception as e:
             if e.__class__.__name__ == 'MaxSizeExceeded':
                 # Post data is too big
                 return HTTPError(request, response, 413)
