@@ -9,51 +9,63 @@ or commonly known as HTTP.
 """
 
 
-from urllib import unquote
-from urlparse import urlparse
-
+from io import BytesIO
 try:
-    from cStringIO import StringIO
+    from urllib.parse import unquote
+    from urllib.parse import urlparse
 except ImportError:
-    from StringIO import StringIO
+    from urllib import unquote
+    from urlparse import urlparse
 
 from circuits.net.sockets import Close, Write
-from circuits.core import handler, Component, Value
+from circuits.core import handler, BaseComponent, Value
 
-import wrappers
-from utils import quoted_slash
-from headers import parseHeaders
-from exceptions import HTTPException
-from errors import HTTPError, NotFound
-from events import Request, Response, Stream
-from errors import Redirect as RedirectError
-from exceptions import Redirect as RedirectException
+from . import wrappers
+from .utils import quoted_slash
+from .exceptions import HTTPException
+from .errors import HTTPError, NotFound
+from .headers import parse_headers, Headers
+from .events import Request, Response, Stream
+from .errors import Redirect as RedirectError
+from .exceptions import Redirect as RedirectException
 
-DEFAULT_TIMEOUT = 3.0
+MAX_HEADER_FRAGENTS = 20
+HTTP_ENCODING = 'utf-8'
+
+try:
+    unicode
+except NameError:
+    unicode = str
 
 
-class HTTP(Component):
+class HTTP(BaseComponent):
     """HTTP Protocol Component
 
     Implements the HTTP server protocol and parses and processes incoming
     HTTP messages creating and sending an appropriate response.
     """
 
-    def __init__(self, *args, **kwargs):
-        super(HTTP, self).__init__(*args, **kwargs)
+    channel = "web"
+
+    def __init__(self, encoding="utf-8", channel=channel):
+        super(HTTP, self).__init__(channel=channel)
+
+        self._encoding = encoding
 
         self._clients = {}
+        self._buffers = {}
 
-    def stream(self, response, data):
+    @handler("stream")
+    def _on_stream(self, response, data):
         if data is not None:
             if data:
                 if response.chunked:
-                    buf = [hex(len(data))[2:], "\r\n", data, "\r\n"]
-                    data = "".join(buf)
+                    buf = [hex(len(data))[2:], b"\r\n", data, b"\r\n"]
+                    data = b"".join(buf)
                 self.push(Write(response.request.sock, data))
             if response.body and not response.done:
                 try:
-                    data = response.body.next()
+                    data = next(response.body)
                 except StopIteration:
                     data = None
                 self.push(Stream(response, data))
@@ -61,43 +73,53 @@ class HTTP(Component):
             if response.body:
                 response.body.close()
             if response.chunked:
-                self.push(Write(response.request.sock, "0\r\n\r\n"))
+                self.push(Write(response.request.sock, b"0\r\n\r\n"))
             if response.close:
                 self.push(Close(response.request.sock))
             response.done = True
 
-    def response(self, response):
-        self.push(Write(response.request.sock, str(response)))
+    @handler("response")
+    def _on_response(self, response):
+        self.push(
+                Write(response.request.sock,
+                    str(response).encode(HTTP_ENCODING)))
 
         if response.stream and response.body:
             try:
-                data = response.body.next()
+                data = next(response.body)
             except StopIteration:
                 data = None
             self.push(Stream(response, data))
         else:
-            body = "".join(response.body)
+            if isinstance(response.body, bytes):
+                body = response.body
+            elif isinstance(response.body, unicode):
+                body = response.body.encode(self._encoding)
+            else:
+                parts = (s if isinstance(s, bytes) else s.encode(self._encoding) for s in response.body)
+                body = b"".join(parts)
 
             if body:
                 if response.chunked:
-                    buf = [hex(len(body))[2:], "\r\n", body, "\r\n"]
-                    body = "".join(buf)
-
+                    buf = [hex(len(body))[2:].encode(), b"\r\n", body, b"\r\n"]
+                    body = b"".join(buf)
                 self.push(Write(response.request.sock, body))
 
                 if response.chunked:
-                    self.push(Write(response.request.sock, "0\r\n\r\n"))
+                    self.push(Write(response.request.sock, b"0\r\n\r\n"))
 
             if not response.stream:
                 if response.close:
                     self.push(Close(response.request.sock))
                 response.done = True
 
-    def disconnect(self, sock):
+    @handler("disconnect")
+    def _on_disconnect(self, sock):
         if sock in self._clients:
             del self._clients[sock]
 
-    def read(self, sock, data):
+    @handler("read")
+    def _on_read(self, sock, data):
         """Read Event Handler
 
         Process any incoming data appending it to an internal buffer.
@@ -117,15 +139,28 @@ class HTTP(Component):
             if not request.body.tell() == contentLength:
                 return
         else:
-            requestline, data = data.split("\n", 1)
-            requestline = requestline.strip()
+            if data.find(b'\r\n\r\n') == -1:
+                buf = self._buffers.setdefault(sock, [])
+                buf.append(data)
+                if len(buf) > MAX_HEADER_FRAGENTS:
+                    del self._buffers[sock]
+                    raise ValueError("Too many HTTP Headers Fragments.")
+                return
+            if sock in self._buffers:
+                self._buffers[sock].append(data)
+                data = ''.join(self._buffers[sock])
+                del self._buffers[sock]
+
+            requestline, data = data.split(b"\r\n", 1)
+            requestline = requestline.strip().decode(
+                    HTTP_ENCODING, "replace")
             method, path, protocol = requestline.split(" ", 2)
             scheme, location, path, params, qs, frag = urlparse(path)
 
             protocol = tuple(map(int, protocol[5:].split(".")))
             request = wrappers.Request(sock, method, scheme, path,
                     protocol, qs)
-            response = wrappers.Response(request)
+            response = wrappers.Response(request, encoding=self._encoding)
             self._clients[sock] = request, response
 
             if frag:
@@ -142,8 +177,6 @@ class HTTP(Component):
             # safely decoded." http://www.ietf.org/rfc/rfc2396.txt, sec 2.4.2
             path = "%2F".join(map(unquote, quoted_slash.split(path)))
 
-            request.path = path.decode("utf-8", "replace")
-
             # Compare request and server HTTP protocol versions, in case our
             # server does not support the requested protocol. Limit our output
             # to min(req, server). We want the following output:
@@ -163,12 +196,19 @@ class HTTP(Component):
             sp = request.server_protocol
             response.protocol = "HTTP/%s.%s" % min(rp, sp)
 
-            headers, body = parseHeaders(StringIO(data))
-            request.headers = headers
-            request.body.write(body)
+            end_of_headers = data.find(b"\r\n\r\n")
+            if end_of_headers > -1:
+                header_data = data[:end_of_headers].decode(
+                        HTTP_ENCODING, "replace")
+                headers = request.headers = parse_headers(header_data)
+            else:
+                headers = request.headers = Headers([])
+
+            request.body.write(data[(end_of_headers + 4):])
 
             if headers.get("Expect", "") == "100-continue":
-                return self.push(Response(wrappers.Response(request, 100)))
+                return self.push(Response(wrappers.Response(request, 100),
+                    encoding=self._encoding))
 
             contentLength = int(headers.get("Content-Length", "0"))
             if request.body.tell() < contentLength:
@@ -197,7 +237,8 @@ class HTTP(Component):
 
         self.push(req)
 
-    def httperror(self, event, request, response, code, **kwargs):
+    @handler("httperror")
+    def _on_httperror(self, event, request, response, code, **kwargs):
         """Default HTTP Error Handler
 
         Default Error Handler that by default just responds with the response
@@ -208,7 +249,10 @@ class HTTP(Component):
         response.body = str(event)
         self.push(Response(response))
 
-    def valuechanged(self, value):
+    @handler("value_changed")
+    def _on_value_changed(self, value):
+        if value.handled:
+            return
         request, response = value.event.args[:2]
         if value.result and not value.errors:
             response.body = value.value
@@ -218,7 +262,7 @@ class HTTP(Component):
             self.push(HTTPError(request, response, error=value.value))
 
     @handler("request_success", "request_filtered")
-    def request_success_or_filtered(self, evt, handler, retval):
+    def _on_request_success_or_filtered(self, evt, handler, retval):
         request, response = evt.args[:2]
 
         if not request.handled and retval is not None:
@@ -250,13 +294,13 @@ class HTTP(Component):
                     if retval.manager is None:
                         retval.manager = self
                     retval.event = evt
-                    retval.onSet = "valuechanged", self
+                    retval.onSet = "value_changed", self
             elif type(retval) is not bool:
                 response.body = retval
                 self.push(Response(response))
 
     @handler("request_failure", "response_failure")
-    def request_or_response_failure(self, evt, handler, error):
+    def _on_request_or_response_failure(self, evt, handler, error):
         if len(evt.args) == 1:
             response = evt.args[0]
             request = response.request
@@ -286,7 +330,8 @@ class HTTP(Component):
         else:
             self.push(HTTPError(request, response, error=error))
 
-    def request_completed(self, evt, handler, retval):
+    @handler("request_completed")
+    def _on_request_completed(self, evt, handler, retval):
         request, response = evt.args[:2]
 
         # Return a 404 response on any of the following:
