@@ -27,7 +27,6 @@ from circuits.net.pollers import Select
 from circuits.tools import inspect, graph
 from circuits import Component, Manager, Debugger
 from circuits import __version__ as systemVersion
-from circuits.core.manager import HAS_MULTIPROCESSING
 from circuits.web import BaseServer, Server, Controller, Static, wsgi
 
 try:
@@ -134,7 +133,7 @@ def main():
         httpd = make_server(address, port, app)
         httpd.serve_forever()
         
-        raise SystemExit, 0
+        raise SystemExit(0)
 
     manager = Manager()
 
@@ -144,24 +143,26 @@ def main():
     poller = opts.type.lower()
     if poller == "poll":
         if Poll is None:
-            print "No poll support available - defaulting to Select..."
+            print("No poll support available - defaulting to Select...")
             Poller = Select
         else:
             Poller = Poll
     elif poller == "epoll":
         if EPoll is None:
-            print "No epoll support available - defaulting to Select..."
+            print("No epoll support available - defaulting to Select...")
             Poller = Select
         else:
             Poller = EPoll
     else:
         Poller = Select
 
+    Poller().register(manager)
+
     if opts.server.lower() == "base":
-        BaseServer(bind, poller=Poller).register(manager)
+        BaseServer(bind).register(manager)
         HelloWorld().register(manager)
     else:
-        Server(bind, poller=Poller).register(manager)
+        Server(bind).register(manager)
         Root().register(manager)
 
     docroot = os.getcwd() if not args else args[0]
@@ -174,15 +175,12 @@ def main():
             profiler.start()
 
     if opts.debug:
-        print graph(manager, name="circuits.web")
-        print
-        print inspect(manager)
+        print(graph(manager, name="circuits.web"))
+        print()
+        print(inspect(manager))
 
-    if opts.mp and HAS_MULTIPROCESSING:
-        for i in range(opts.mp):
-            manager.start(process=True)
-    else:
-        print "No multiprocessing support available"
+    for i in range(opts.mp):
+        manager.start(process=True)
 
     manager.run()
 
