@@ -15,13 +15,21 @@ from circuits import handler, Component
 
 class Sessions(Component):
 
+    channel = "web"
+
     def __init__(self, name="circuits.session", *args, **kwargs):
         super(Sessions, self).__init__(*args, **kwargs)
 
         self._name = name
         self._data = defaultdict(dict)
 
-    @handler("request", filter=True)
+    def _load(self, id):
+        return self._data[id]
+
+    def _save(self, id, data):
+        self._data[id] = data
+
+    @handler("request", filter=True, priority=10)
     def request(self, request, response):
         if self._name in request.cookie:
             id = request.cookie[self._name].value
@@ -29,5 +37,5 @@ class Sessions(Component):
             id = str(uuid())
 
         request.sid = id
-        request.session = self._data[id]
+        request.session = self._load(id)
         response.cookie[self._name] = id
