@@ -8,28 +8,29 @@ This module implements utility functions.
 """
 
 import re
-import gzip
 import zlib
 import time
 import struct
-import urllib
 from cgi import escape
-from urlparse import urljoin as _urljoin
-
 try:
-    from cStringIO import StringIO
+    from urllib.parse import urljoin as _urljoin
 except ImportError:
-    from StringIO import StringIO
+    from urlparse import urljoin as _urljoin
 
 try:
-    from urlparse import parse_qs
+    from io import StringIO
+except ImportError:
+    from io import StringIO
+
+try:
+    from urllib.parse import parse_qs
 except ImportError:
     from cgi import parse_qs
 
-from constants import HTTP_STATUS_CODES
+from .constants import HTTP_STATUS_CODES
 
 quoted_slash = re.compile("(?i)%2F")
-image_map_pattern = re.compile(r"[0-9]+,[0-9]+")
+image_map_pattern = re.compile("[0-9]+,[0-9]+")
 
 def parseQueryString(query_string, keep_blank_values=True):
     """parseQueryString(query_string) -> dict
@@ -46,11 +47,11 @@ def parseQueryString(query_string, keep_blank_values=True):
         return {"x": int(pm[0]), "y": int(pm[1])}
     else:
         pm = parse_qs(query_string, keep_blank_values)
-        return dict((k, v[0]) for k, v in pm.iteritems() if v)
+        return dict((k, v[0]) for k, v in pm.items() if v)
 
 def dictform(form):
     d = {}
-    for key in form.keys():
+    for key in list(form.keys()):
         values = form[key]
         if isinstance(values, list):
             d[key] = []
@@ -72,10 +73,12 @@ def compress(body, compress_level):
     """Compress 'body' at the given compress_level."""
 
     # Header
-    yield "\037\213\010\0" + struct.pack("<L", long(time.time())) + "\002\377"
+    yield b"\037\213\010\0" \
+            + struct.pack("<L", int(time.time())) \
+            + b"\002\377"
 
     size = 0
-    crc = zlib.crc32("")
+    crc = zlib.crc32(b"")
 
     zobj = zlib.compressobj(
         compress_level,
@@ -86,21 +89,16 @@ def compress(body, compress_level):
     )
 
     for chunk in body:
+        if not isinstance(chunk, bytes):
+            chunk = chunk.encode("utf-8")
+
         size += len(chunk)
         crc = zlib.crc32(chunk, crc)
         yield zobj.compress(chunk)
 
-    yield zobj.flush() + struct.pack("<l", crc) + \
-            struct.pack("<L", size & 0xFFFFFFFFL)
-
-def decompress(body):
-    zbuf = StringIO()
-    zbuf.write(body)
-    zbuf.seek(0)
-    zfile = gzip.GzipFile(mode='rb', fileobj=zbuf)
-    data = zfile.read()
-    zfile.close()
-    return data
+    yield zobj.flush() \
+            + struct.pack("<l", crc) \
+            + struct.pack("<L", size & 0xFFFFFFFF)
 
 def url(request, path="", qs="", script_name=None, base=None, relative=None):
     """Create an absolute URL for the given path.
@@ -211,7 +209,7 @@ def get_ranges(headervalue, content_length):
         if start:
             if not stop:
                 stop = content_length - 1
-            start, stop = map(int, (start, stop))
+            start, stop = list(map(int, (start, stop)))
             if start >= content_length:
                 # From rfc 2616 sec 14.16:
                 # "If the server receives a request (other than one
@@ -239,31 +237,3 @@ def get_ranges(headervalue, content_length):
             result.append((content_length - int(stop), content_length))
     
     return result
-
-def url_quote(s, charset="utf-8", safe="/:"):
-    """URL encode a single string with a given encoding.
-
-    :param s: the string to quote.
-    :param charset: the charset to be used.
-    :param safe: an optional sequence of safe characters.
-    """
-
-    if isinstance(s, unicode):
-        s = s.encode(charset)
-    elif not isinstance(s, str):
-        s = str(s)
-    return urllib.quote(s, safe=safe)
-
-def url_unquote(s, charset="utf-8", errors="ignore"):
-    """URL decode a single string with a given decoding.
-
-    Per default encoding errors are ignored.  If you want a different behavior
-    you can set `errors` to ``"replace"`` or ``"strict"``.  In strict mode a
-    `HTTPUnicodeError` is raised.
-
-    :param s: the string to unquote.
-    :param charset: the charset to be used.
-    :param errors: the error handling for the charset decoding.
-    """
-
-    return urllib.unquote(s).decode(charset, errors)
