@@ -15,7 +15,7 @@ from circuits.io import stdin
 from circuits import handler, Component
 from circuits import __version__ as systemVersion
 from circuits.net.sockets import TCPClient, Connect
-from circuits.net.protocols.irc import IRC, PRIVMSG, USER, NICK, JOIN
+from circuits.net.protocols.irc import IRC, PRIVMSG, USER, NICK, JOIN, Nick
 
 USAGE = "%prog [options] host [port]"
 VERSION = "%prog v" + systemVersion
@@ -49,7 +49,7 @@ def parse_options():
 
     if len(args) < 1:
         parser.print_help()
-        raise SystemExit, 1
+        raise SystemExit(1)
 
     return opts, args
 
@@ -73,46 +73,46 @@ class Client(Component):
         self.ircchannel = opts.channel
 
         self += (TCPClient(channel=self.channel) + IRC(channel=self.channel))
-        self.push(Connect(self.host, self.port), "connect")
+        self.fire(Connect(self.host, self.port), "connect")
 
     def connected(self, host, port):
-        print "Connected to %s:%d" % (host, port)
+        print("Connected to %s:%d" % (host, port))
 
         nick = self.nick
         hostname = self.hostname
         name = "%s on %s using circuits/%s" % (nick, hostname, systemVersion)
 
-        self.push(USER(nick, hostname, host, name))
-        self.push(NICK(nick))
+        self.fire(USER(nick, hostname, host, name))
+        self.fire(NICK(nick))
 
     def disconnected(self):
-        self.push(Connect(self.opts.host, self.opts.port), "connect")
+        self.fire(Connect(self.opts.host, self.opts.port), "connect")
 
     def numeric(self, source, target, numeric, args, message):
         if numeric == 1:
-            self.push(JOIN(self.ircchannel))
+            self.fire(JOIN(self.ircchannel))
         elif numeric == 433:
             self.nick = newnick = "%s_" % self.nick
-            self.push(Nick(newnick), "NICK")
+            self.fire(Nick(newnick), "NICK")
 
     def join(self, source, channel):
         if source[0].lower() == self.nick.lower():
-            print "Joined %s" % channel
+            print("Joined %s" % channel)
         else:
-            print "--> %s (%s) has joined %s" % (source[0], source, channel)
+            print("--> %s (%s) has joined %s" % (source[0], source, channel))
 
     def notice(self, source, target, message):
-        print "-%s- %s" % (source[0], message)
+        print("-%s- %s" % (source[0], message))
 
     def message(self, source, target, message):
         if target[0] == "#":
-            print "<%s> %s" % (target, message)
+            print("<%s> %s" % (target, message))
         else:
-            print "-%s- %s" % (source, message)
+            print("-%s- %s" % (source, message))
 
     @handler("read", target="stdin")
     def stdin_read(self, data):
-        self.push(PRIVMSG(self.ircchannel, data.strip()))
+        self.fire(PRIVMSG(self.ircchannel, data.strip()))
 
 ###
 ### Main
