@@ -4,7 +4,10 @@
 
 """Debugger Tests"""
 
-from StringIO import StringIO
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO
 
 from circuits import Debugger
 from circuits.core import Event, Component
@@ -197,7 +200,7 @@ def test_tick_exceptions():
     debugger = Debugger(file=stderr)
     debugger.register(app)
     while app:
-        app.flush()
+        app.tick()
     stderr.seek(0)
     stderr.truncate()
 
@@ -209,7 +212,9 @@ def test_tick_exceptions():
 
     stderr.seek(0)
     s = stderr.read().strip()
-    assert s.startswith("<Error[*:exception] [<type 'exceptions.Exception'>, Exception()")
+
+    assert s.startswith("<Error[*:exception] [<class 'Exception'>, Exception()") \
+            or s.startswith("<Error[*:exception] [<type 'exceptions.Exception'>, Exception()")
     stderr.seek(0)
     stderr.truncate()
 
@@ -311,4 +316,5 @@ def test_Logger_error():
     app.push(e)
     app.flush()
     app.flush()
-    assert logger.msg.startswith("ERROR <listener on ('test',) {target='*', priority=0.0}> (<type 'exceptions.Exception'>):")
+    assert logger.msg.startswith("ERROR <listener on ('test',) {target='*', priority=0.0}> (<class 'Exception'>):") \
+        or logger.msg.startswith("ERROR <listener on ('test',) {target='*', priority=0.0}> (<type 'exceptions.Exceptio")
