@@ -8,6 +8,7 @@ import pytest
 
 from circuits import Task, Pool
 
+
 def f():
     x = 0
     i = 0
@@ -16,6 +17,7 @@ def f():
         i += 1
     return x
 
+
 def test():
     p = Pool()
     p.start()
@@ -24,8 +26,10 @@ def test():
 
     assert pytest.wait_for(x, "result")
 
-    assert x.result
-    v = x.value
-    assert v == 1000000
+    result = x.result
+    assert result
+
+    value = x.value
+    assert value == 1000000
 
     p.stop()
