@@ -5,9 +5,11 @@ from collections import defaultdict
 from circuits import Event, Component
 from circuits.net.protocols import LP
 
+
 class Read(Event):
     """Read Event"""
 
+
 class App(Component):
 
     lines = []
@@ -15,6 +17,7 @@ class App(Component):
     def line(self, line):
         self.lines.append(line)
 
+
 class AppServer(Component):
 
     channel = "server"
@@ -24,6 +27,7 @@ class AppServer(Component):
     def line(self, sock, line):
         self.lines.append((sock, line))
 
+
 def test():
     app = App()
     LP().register(app)
@@ -31,7 +35,7 @@ def test():
     while app:
         app.flush()
 
-    app.push(Read("1\n2\r\n3\n4"))
+    app.push(Read(b"1\n2\r\n3\n4"))
 
     while app:
         app.flush()
@@ -40,17 +44,18 @@ def test():
     assert app.lines[1] == "2"
     assert app.lines[2] == "3"
 
+
 def test_server():
     app = AppServer()
-    buffers = defaultdict(str)
+    buffers = defaultdict(bytes)
     LP(getBuffer=buffers.__getitem__,
             updateBuffer=buffers.__setitem__).register(app)
 
     while app:
         app.flush()
 
-    app.push(Read(1, "1\n2\r\n3\n4"))
-    app.push(Read(2, "1\n2\r\n3\n4"))
+    app.push(Read(1, b"1\n2\r\n3\n4"))
+    app.push(Read(2, b"1\n2\r\n3\n4"))
 
     while app:
         app.flush()
