@@ -3,18 +3,14 @@
 import pytest
 
 from circuits import Manager
-from circuits.core import pollers
 from circuits.net.sockets import Pipe
+from circuits.core.pollers import Select
 from circuits.net.sockets import Close, Write
 
-from client import Client
+from .client import Client
 
 def pytest_generate_tests(metafunc):
-    metafunc.addcall(funcargs={"Poller": pollers.Select})
-    if pollers.HAS_POLL:
-        metafunc.addcall(funcargs={"Poller": pollers.Poll})
-    if pollers.HAS_EPOLL:
-        metafunc.addcall(funcargs={"Poller": pollers.EPoll})
+    metafunc.addcall(funcargs={"Poller": Select})
 
 def test_pipe(Poller):
     m = Manager() + Poller()
@@ -32,11 +28,11 @@ def test_pipe(Poller):
         assert pytest.wait_for(a, "ready")
         assert pytest.wait_for(b, "ready")
 
-        a.push(Write("foo"))
-        assert pytest.wait_for(b, "data", "foo")
+        a.push(Write(b"foo"))
+        assert pytest.wait_for(b, "data", b"foo")
 
-        b.push(Write("foo"))
-        assert pytest.wait_for(a, "data", "foo")
+        b.push(Write(b"foo"))
+        assert pytest.wait_for(a, "data", b"foo")
 
         a.push(Close())
         assert pytest.wait_for(a, "disconnected")
