@@ -1,3 +1,4 @@
+import pytest
 
 from circuits.web import Server, Controller
 
@@ -13,7 +14,7 @@ def test(webapp):
     client.start()
 
     client.push(Connect())
-    while not client.connected: pass
+    assert pytest.wait_event(client, 'connected', target='client')
 
     client.push(Request("GET", "/"))
     while client.response is None: pass
@@ -25,4 +26,4 @@ def test(webapp):
     assert response.message == "OK"
 
     s = response.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
