@@ -1,6 +1,9 @@
 #!/usr/bin/env python
 
-from httplib import HTTPConnection
+try:
+    from httplib import HTTPConnection
+except ImportError:
+    from http.client import HTTPConnection
 from circuits.web import Controller
 
 class Root(Controller):
@@ -12,11 +15,12 @@ def test(webapp):
     connection.auto_open = False
     connection.connect()
 
-    for i in xrange(2):
+    for i in range(2):
         connection.request("GET", "/")
         response = connection.getresponse()
         assert response.status == 200
         assert response.reason == "OK"
-        assert response.read() == "Hello World!"
+        s = response.read()
+        assert s == b"Hello World!"
 
     connection.close()
