@@ -1,11 +1,10 @@
-#!/usr/bin/env python
-
-from urllib2 import HTTPError, HTTPDigestAuthHandler
-from urllib2 import urlopen, build_opener, install_opener
-
 from circuits.web import Controller
 from circuits.web.tools import check_auth, digest_auth
 
+from .helpers import HTTPError, HTTPError, HTTPDigestAuthHandler
+from .helpers import urlopen, build_opener, install_opener
+
+
 class Root(Controller):
 
     def index(self):
@@ -20,7 +19,7 @@ class Root(Controller):
 def test(webapp):
     try:
         f = urlopen(webapp.server.base)
-    except HTTPError, e:
+    except HTTPError as e:
         assert e.code == 401
         assert e.msg == "Unauthorized"
     else:
@@ -33,4 +32,4 @@ def test(webapp):
 
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
