@@ -1,12 +1,14 @@
 #!/usr/bin/env python
 
-from urllib2 import urlopen
-from rfc822 import parsedate
 from datetime import datetime
-from time import gmtime, mktime
+from time import mktime
+from email.utils import parsedate
 
 from circuits.web import Controller
 
+from .helpers import urlopen
+
+
 class Root(Controller):
 
     def index(self):
@@ -20,15 +22,15 @@ class Root(Controller):
 def test(webapp):
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s  == "Hello World!"
+    assert s  == b"Hello World!"
     expires = f.headers["Expires"]
-    diff = (mktime(parsedate(expires)) - mktime(gmtime()))
+    diff = (mktime(parsedate(expires)) - mktime(datetime.utcnow().timetuple()))
     assert 60 - (60 * 0.1) < diff < 60 + (60 * 0.1) # diff is about 60 +- 10%
 
 def test_nocache(webapp):
     f = urlopen("%s/nocache" % webapp.server.base)
     s = f.read()
-    assert s  == "Hello World!"
+    assert s  == b"Hello World!"
 
     expires = f.headers["Expires"]
     pragma = f.headers["Pragma"]
