@@ -1,12 +1,23 @@
 #!/usr/bin/env python
 
-from urllib2 import build_opener, Request
+try:
+    from gzip import decompress
+except ImportError:
+    import zlib
+    decompress = zlib.decompressobj(16+zlib.MAX_WBITS).decompress
+
+try:
+    from urllib.request import Request
+except ImportError:
+    from urllib2 import Request
 
 from circuits import handler, Component
 
 from circuits.web import Controller
 from circuits.web.tools import gzip
-from circuits.web.utils import decompress
+
+from .helpers import build_opener
+
 
 class Gzip(Component):
 
@@ -21,6 +32,9 @@ class Root(Controller):
         return "Hello World!"
 
 def test(webapp):
+    from circuits import Debugger
+    Debugger().register(webapp)
+
     gzip = Gzip()
     gzip.register(webapp)
 
@@ -30,6 +44,6 @@ def test(webapp):
 
     f = opener.open(request)
     s = decompress(f.read())
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
 
     gzip.unregister()
