@@ -1,13 +1,18 @@
 #!/usr/bin/env python
 
 import sys
-from urllib2 import urlopen
-from StringIO import StringIO
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO
 from socket import gaierror, gethostbyname, gethostname
 
 from circuits.web import Controller, Logger
 from circuits.web.loggers import formattime
 
+from .helpers import urlopen
+
+
 class DummyLogger(object):
 
     def __init__(self):
@@ -30,7 +35,7 @@ def test_file(webapp):
 
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
 
     logfile.seek(0)
     s = logfile.read().strip()
@@ -52,7 +57,7 @@ def test_file(webapp):
     d["f"] = ""
     d["a"] = "Python-urllib/%s" % sys.version[:3]
 
-    keys = d.keys()
+    keys = list(d.keys())
 
     for k in keys:
         assert d[k] in s
@@ -67,7 +72,7 @@ def test_logger(webapp):
 
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
 
     s = logobj.message
 
@@ -88,7 +93,7 @@ def test_logger(webapp):
     d["f"] = ""
     d["a"] = "Python-urllib/%s" % sys.version[:3]
 
-    keys = d.keys()
+    keys = list(d.keys())
 
     for k in keys:
         assert d[k] in s
@@ -104,7 +109,7 @@ def test_filename(webapp, tmpdir):
 
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
 
     logfile.seek(0)
     s = logfile.read().strip()
@@ -126,7 +131,7 @@ def test_filename(webapp, tmpdir):
     d["f"] = ""
     d["a"] = "Python-urllib/%s" % sys.version[:3]
 
-    keys = d.keys()
+    keys = list(d.keys())
 
     for k in keys:
         assert d[k] in s
