@@ -1,11 +1,17 @@
 #!/usr/bin/env python
 
-from StringIO import StringIO
-from urllib2 import urlopen, Request
+from io import StringIO
+
+try:
+    from urllib.request import Request
+except ImportError:
+    from urllib2 import Request
 
 from circuits.web import Controller
 
-from multipartform import MultiPartForm
+from .multipartform import MultiPartForm
+from .helpers import urlopen
+
 
 class Root(Controller):
 
@@ -19,21 +25,21 @@ def test(webapp):
     form = MultiPartForm()
     form["description"] = "Hello World!"
 
-    fd = StringIO("Hello World!")
+    fd = StringIO(b"Hello World!".decode("utf-8"))
     form.add_file("file", "helloworld.txt", fd)
 
     # Build the request
     request = Request(webapp.server.base)
-    body = str(form)
+    body = str(form).encode('utf-8')
     request.add_header("Content-Type", form.get_content_type())
     request.add_header("Content-Length", len(body))
     request.add_data(body)
 
     f = urlopen(request)
     s = f.read()
-    lines = s.split("\n")
+    lines = s.split(b"\n")
 
-    assert lines[0] == "Filename: helloworld.txt"
-    assert lines[1] == "Description: Hello World!"
-    assert lines[2] == "Content:"
-    assert lines[3] == "Hello World!"
+    assert lines[0] == b"Filename: helloworld.txt"
+    assert lines[1] == b"Description: Hello World!"
+    assert lines[2] == b"Content:"
+    assert lines[3] == b"Hello World!"
