@@ -1,9 +1,8 @@
-#!/usr/bin/env python
-
-from urllib2 import urlopen, HTTPError
-
 from circuits import Component
 
+from .helpers import urlopen, HTTPError
+
+
 class Root(Component):
 
     channel = "web"
@@ -14,7 +13,7 @@ class Root(Component):
 def test(webapp):
     try:
         f = urlopen(webapp.server.base)
-    except HTTPError, e:
+    except HTTPError as e:
         assert e.code == 500
     else:
         assert False
