@@ -1,18 +1,20 @@
 #!/usr/bin/env python
 
 import os
-from urllib2 import urlopen
 from tempfile import mkstemp
 
 from circuits import handler
 from circuits.web import Controller
 
+from .helpers import urlopen
+
+
 class Root(Controller):
 
     @handler("started", priority=1.0, target="*")
     def _on_started(self, component, mode):
         fd, self.filename = mkstemp()
-        os.write(fd, "Hello World!")
+        os.write(fd, b"Hello World!")
         os.close(fd)
 
     @handler("stopped", target="(")
@@ -25,7 +27,7 @@ class Root(Controller):
 def test(webapp):
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s  == "Hello World!"
+    assert s  == b"Hello World!"
     contentType = f.headers["Content-Type"]
     contentDisposition = f.headers["Content-Disposition"]
     assert contentType == "application/x-download"
