@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 
-import urllib2
-from cookielib import CookieJar
-
 from circuits.web import Controller, Sessions
 
+from .helpers import build_opener, HTTPCookieProcessor
+from .helpers import CookieJar
+
+
 class Root(Controller):
 
     def index(self, name=None):
@@ -19,16 +20,16 @@ def test(webapp):
     Sessions().register(webapp)
 
     cj = CookieJar()
-    opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cj))
+    opener = build_opener(HTTPCookieProcessor(cj))
 
     f = opener.open(webapp.server.base)
     s = f.read() 
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
 
     f = opener.open(webapp.server.base + "/test")
     s = f.read()
-    assert s == "Hello test"
+    assert s == b"Hello test"
 
     f = opener.open(webapp.server.base)
     s = f.read()
-    assert s == "Hello test"
+    assert s == b"Hello test"
