@@ -1,10 +1,11 @@
 #!/usr/bin/env python
 
-from urllib2 import urlopen
-
 from circuits.web import Controller
 from circuits import Event, Component
 
+from .helpers import urlopen
+
+
 class Hello(Event):
     """Hello Event"""
 
@@ -23,4 +24,4 @@ def test(webapp):
 
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
