@@ -1,18 +1,13 @@
 #!/usr/bin/env python
 
 import os
-from urllib2 import urlopen
-
-import pytest
-pytest.skip()
-
-from circuits.core.manager import HAS_MULTIPROCESSING
-if not HAS_MULTIPROCESSING:
-    pytest.skip("Skip: No multiprocessing support")
 
 from circuits.web import Controller
 from circuits import Event, Component
 
+from .helpers import urlopen
+
+
 class Hello(Event):
     """Hello Event"""
 
@@ -31,5 +26,5 @@ def test(webapp):
     t.start(link=webapp, process=True)
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello %d i'm %d" % (os.getpid(), t._task.pid)
+    assert s.decode() == "Hello %d i'm %d" % (os.getpid(), t._proc.pid)
     t.stop()
