@@ -1,10 +1,16 @@
 #!/usr/bin/env python
 
-from urllib2 import urlopen
+try:
+    from urllib.request import urlopen
+except ImportError:
+    from urllib2 import urlopen
 
 from circuits.web import Controller
 from circuits.web.wsgi import Application
 
+from .helpers import urlopen
+
+
 class Root(Controller):
 
     def index(self):
@@ -16,4 +22,4 @@ application = Application() + Root()
 def test(webapp):
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
