@@ -1,9 +1,10 @@
 #!/usr/bin/env python
 
-from urllib2 import urlopen
-
 from circuits.web.wsgi import Gateway
 
+from .helpers import urlopen
+
+
 def application(environ, start_response):
     status = "200 OK"
     response_headers = [("Content-type", "text/plain")]
@@ -22,10 +23,10 @@ def test(webapp):
 
     f = urlopen(webapp.server.base)
     s = f.read()
-    assert s == "Hello World!"
+    assert s == b"Hello World!"
 
     f = urlopen("%s/foo" % webapp.server.base)
     s = f.read()
-    assert s == "Foo"
+    assert s == b"Foo"
 
     foo.unregister()
